==> pipewire-docs-1%3A0.3.32-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/page_pipewire_modules.js <==
var page_pipewire_modules =
[
    [ "PipeWire Module: Access", "page_module_access.html", null ],
    [ "PipeWire Module: Adapter", "page_module_adapter.html", null ],
    [ "PipeWire Module: Client Device", "page_module_client_device.html", null ],
    [ "PipeWire Module: Client Node", "page_module_client_node.html", null ],
    [ "PipeWire Module: Echo Cancel", "page_module_echo_cancel.html", null ],
    [ "PipeWire Module: Example Sink", "page_module_example_sink.html", null ],
    [ "PipeWire Module: Example Source", "page_module_example_source.html", null ],
    [ "PipeWire Module: Filter-Chain", "page_module_filter_chain.html", null ],
    [ "PipeWire Module: Link Factory", "page_module_link_factory.html", null ],
    [ "PipeWire Module: Loopback", "page_module_loopback.html", null ],
    [ "PipeWire Module: Metadata", "page_module_metadata.html", null ],
    [ "PipeWire Module: Portal", "page_module_portal.html", null ],
    [ "PipeWire Module: Profiler", "page_module_profiler.html", null ],
    [ "PipeWire Module: Protocol Native", "page_module_protocol_native.html", null ],
    [ "PipeWire Module: Protocol Pulse", "page_module_protocol_pulse.html", null ],
    [ "PipeWire Module: Protocol Simple", "page_module_protocol_simple.html", null ],
    [ "PipeWire Module: Pulse Tunnel", "page_module_pulse_tunnel.html", null ],
    [ "PipeWire Module: ROC sink", "page_module_roc_sink.html", null ],
    [ "PipeWire Module: ROC source", "page_module_roc_source.html", null ],
    [ "PipeWire Module: RT", "page_module_rt.html", null ],
    [ "PipeWire Module: RTKit", "page_module_rtkit.html", null ],
    [ "PipeWire Module: Session Manager", "page_module_session_manager.html", null ],
    [ "PipeWire Module: Zeroconf Discover", "page_module_zeroconf_discover.html", null ]
];

==> pipewire-docs-1%3A0.3.63-4-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/page_pipewire_modules.js <==
var page_pipewire_modules =
[
    [ "PipeWire Module: Access", "page_module_access.html", null ],
    [ "PipeWire Module: Adapter", "page_module_adapter.html", null ],
    [ "PipeWire Module: AVB", "page_module_avb.html", null ],
    [ "PipeWire Module: Client Device", "page_module_client_device.html", null ],
    [ "PipeWire Module: Client Node", "page_module_client_node.html", null ],
    [ "PipeWire Module: Echo Cancel", "page_module_echo_cancel.html", null ],
    [ "PipeWire Module: Example Sink", "page_module_example_sink.html", null ],
    [ "PipeWire Module: Example Source", "page_module_example_source.html", null ],
    [ "PipeWire Module: Fallback Sink", "page_module_fallback_sink.html", null ],
    [ "PipeWire Module: Filter-Chain", "page_module_filter_chain.html", null ],
    [ "PipeWire Module: Link Factory", "page_module_link_factory.html", null ],
    [ "PipeWire Module: Loopback", "page_module_loopback.html", null ],
    [ "PipeWire Module: Metadata", "page_module_metadata.html", null ],
    [ "PipeWire Module: Unix Pipe Tunnel", "page_module_pipe_tunnel.html", null ],
    [ "PipeWire Module: Portal", "page_module_portal.html", null ],
    [ "PipeWire Module: Profiler", "page_module_profiler.html", null ],
    [ "PipeWire Module: Protocol Native", "page_module_protocol_native.html", null ],
    [ "PipeWire Module: Protocol Pulse", "page_module_protocol_pulse.html", null ],
    [ "PipeWire Module: Protocol Simple", "page_module_protocol_simple.html", null ],
    [ "PipeWire Module: Pulse Tunnel", "page_module_pulse_tunnel.html", null ],
    [ "PipeWire Module: AirPlay Sink", "page_module_raop_sink.html", null ],
    [ "PipeWire Module: RAOP Discover", "page_module_raop_discover.html", null ],
    [ "PipeWire Module: ROC sink", "page_module_roc_sink.html", null ],
    [ "PipeWire Module: ROC source", "page_module_roc_source.html", null ],
    [ "PipeWire Module: RTP sink", "page_module_rtp_sink.html", null ],
    [ "PipeWire Module: RTP source", "page_module_rtp_source.html", null ],
    [ "PipeWire Module: RT", "page_module_rt.html", null ],
    [ "PipeWire Module: Session Manager", "page_module_session_manager.html", null ],
    [ "PipeWire Module: X11 Bell", "page_module_x11_bell.html", null ],
    [ "PipeWire Module: Zeroconf Discover", "page_module_zeroconf_discover.html", null ]
];
